// register-provider.js

const {registerProvider, setLogo} = require('../routes');
const logger = require('../logger');
const {assertValidProviderConfig} = require('../config-validator');

const register = async (serviceAccount, providerConfig) => {
  // validate the provider config (the serviceAccount is just user)
  assertValidProviderConfig(providerConfig);
  // begin registering
  const providerInfo = {
    name: providerConfig.name,
    info: providerConfig.info,
    redirect_uri: Object.values(providerConfig.redirectUris) // works for arrays as well
  };
  const provider = await registerProvider(serviceAccount, providerInfo);
  logger.info('registered service provider: ', providerConfig.name);
  // set the provider logo if appropriate
  if (providerConfig.logoPath) {
    try {
      await setLogo(serviceAccount, provider._id, providerConfig.logoPath);
    } catch (e) {
      logger.error('setLogo error', e.message);
    }
  }
  // and format the redirectUris
  const formatted = {
    ...provider,
    redirectUris: providerConfig.redirectUris
  };
  return formatted;
};

module.exports = register;
