'use strict';
// yggio-request.js

const request = require('request-promise');
const get = require('lodash.get');
const pickBy = require('lodash.pickby');

let yggioUrl = null;

const yggioRequest = async ({
  method,
  user,
  body,
  uri,
  qs,
  json = true,
  headers,
  formData
}) => {
  if (!yggioUrl) {
    throw new Error('yggioUrl is not set');
  }
  if (!uri) {
    throw new Error('yggio api uri is missing');
  }
  const accessToken = get(user, 'accessToken');

  const data = pickBy({
    method,
    baseUrl: yggioUrl,
    uri,
    ...accessToken ? {auth: {bearer: accessToken}} : {},
    qs,
    body,
    json,
    headers,
    formData
  }, Boolean);
  return request(data);
};

module.exports = {
  setYggioUrl: url => {
    yggioUrl = url;
  },
  get: async requestObj => yggioRequest({
    ...requestObj,
    method: 'GET'
  }),
  post: async requestObj => yggioRequest({
    ...requestObj,
    method: 'POST'
  }),
  put: async requestObj => yggioRequest({
    ...requestObj,
    method: 'PUT'
  }),
  delete: async requestObj => yggioRequest({
    ...requestObj,
    method: 'DELETE'
  }),
  request
};
